@@ -8,7 +8,7 @@ use std::{
     str::FromStr,
 };
 
-use platforms::target::*;
+use build_target::{Arch, Env, Os};
 use semver::Version;
 use serde::{Deserialize, Serialize};
 use zip::ZipArchive;
@@ -58,51 +58,56 @@ struct PackageInfoCatalogEntry<'a> {
 }
 
 fn main() -> Result<(), Box<dyn std::error::Error>> {
+    // we cannot (and don't really need to) download nethost when building on docs.rs so we exit early.
     if cfg!(feature = "private-docs-rs") {
         println!("Returning early because private-docs-rs feature was enabled");
         return Ok(());
     }
 
-    let target = match (
-        platforms::TARGET_OS,
-        platforms::TARGET_ARCH,
-        platforms::TARGET_ENV,
-    ) {
-        (OS::Windows, Arch::X86, _) => "win-x86",
-        (OS::Windows, Arch::X86_64, _) => "win-x64",
-        (OS::Windows, Arch::ARM, _) => "win-arm",
-        (OS::Windows, Arch::AARCH64, _) => "win-arm64",
-        (OS::Linux, Arch::X86_64, Some(Env::Musl)) => "linux-musl-x64",
-        (OS::Linux, Arch::ARM, Some(Env::Musl)) => "linux-musl-arm",
-        (OS::Linux, Arch::AARCH64, Some(Env::Musl)) => "linux-musl-arm64",
-        (OS::Linux, Arch::X86_64, _) => "linux-x64",
-        (OS::Linux, Arch::ARM, _) => "linux-arm",
-        (OS::Linux, Arch::AARCH64, _) => "linux-arm64",
-        (OS::iOS, Arch::X86_64, _) => "osx-x64",
+    let os = Os::target().unwrap();
+    let arch = Arch::target().unwrap();
+    let env = Env::target().unwrap();
+
+    let target = match (&os, arch, env) {
+        (Os::Windows, Arch::X86,     _) => "win-x86",
+        (Os::Windows, Arch::X86_64,  _) => "win-x64",
+        (Os::Windows, Arch::ARM,     _) => "win-arm",
+        (Os::Windows, Arch::AARCH64, _) => "win-arm64",
+        (Os::Linux,   Arch::X86_64,  Env::Musl) => "linux-musl-x64",
+        (Os::Linux,   Arch::ARM,     Env::Musl) => "linux-musl-arm",
+        (Os::Linux,   Arch::AARCH64, Env::Musl) => "linux-musl-arm64",
+        (Os::Linux,   Arch::X86_64,  _) => "linux-x64",
+        (Os::Linux,   Arch::ARM,     _) => "linux-arm",
+        (Os::Linux,   Arch::AARCH64, _) => "linux-arm64",
+        (Os::MacOs,   Arch::X86_64,  _) => "osx-x64",
         _ => panic!("platform not supported."),
     };
 
     let out_dir = env::var("OUT_DIR")?;
-    let runtimes_dir = Path::new(&out_dir)
-        .parent().unwrap()
-        .parent().unwrap()
-        .parent().unwrap()
-        .join("runtimes")
+    let runtime_dir = Path::new(&out_dir)
+        .parent()
+        .unwrap()
+        .parent()
+        .unwrap()
+        .parent()
+        .unwrap()
+        .join("nethost")
         .join(target);
-    if !runtimes_dir.exists() || runtimes_dir.read_dir()?.next().is_none() {
-        create_dir_all(&runtimes_dir)?;
-        download_nethost(target, &runtimes_dir)?;
+    if !runtime_dir.exists() || runtime_dir.read_dir()?.next().is_none() {
+        create_dir_all(&runtime_dir)?;
+        download_nethost(target, &runtime_dir)?;
     }
 
-    println!("cargo:rustc-link-search={}", runtimes_dir.into_os_string().to_str().unwrap());
+    println!("cargo:rerun-if-changed={}", runtime_dir.to_str().unwrap());
+    println!("cargo:rustc-link-search={}", runtime_dir.to_str().unwrap());
 
     // NOTE: for some reason we need the rustc argument here, but the link attribute in bindings/nethost.rs for unix.
     // For more information see https://github.com/OpenByteDev/netcorehost/issues/2.
-    match platforms::TARGET_OS {
-        OS::Windows => {
+    match os {
+        Os::Windows => {
             println!("cargo:rustc-link-lib=libnethost");
         }
-        OS::iOS => {
+        Os::MacOs => {
             // untestet
             // println!("cargo:rustc-link-lib=dylib=c++");
             // println!("cargo:rustc-link-lib=static=nethost");
