@@ -1,4 +1,9 @@
-#![feature(maybe_uninit_uninit_array, maybe_uninit_extra, maybe_uninit_slice)]
+#![feature(
+    maybe_uninit_uninit_array,
+    maybe_uninit_extra,
+    maybe_uninit_slice,
+    negative_impls
+)]
 #![allow(clippy::missing_safety_doc)]
 
 //! A Rust library for hosting .NET Core application.
@@ -26,9 +31,9 @@
 //! # use netcorehost::pdcstring::PdCString;
 //! # use netcorehost::{nethost, hostfxr::HostExitCode};
 //! # use std::path::Path;
+//! # use std::str::FromStr;
 //! # fn run_app() -> Result<(), Box<dyn std::error::Error>> {
 //! let assembly_path = PdCString::from_str("./Test.dll")?;
-//!
 //! let hostfxr = nethost::load_hostfxr()?;
 //! let context = hostfxr.initialize_for_dotnet_command_line(assembly_path)?;
 //! let result = context.run_app();
@@ -54,17 +59,18 @@
 //! #
 //! # use netcorehost::nethost;
 //! # use netcorehost::pdcstring::PdCString;
+//! # use std::str::FromStr;
 //! #
 //! # fn hello_world() -> Result<(), Box<dyn std::error::Error>> {
 //! let hostfxr = nethost::load_hostfxr()?;
 //! let context =
 //!     hostfxr.initialize_for_runtime_config(PdCString::from_str("Test.runtimeconfig.json")?)?;
-//! let fn_loader =
+//! let mut fn_loader =
 //!     context.get_delegate_loader_for_assembly(PdCString::from_str("Test.dll")?)?;
 //! let hello = fn_loader.get_function_pointer_with_default_signature(
 //!     PdCString::from_str("Test.Program, Test")?,
 //!     PdCString::from_str("Hello")?,
-//! );
+//! )?;
 //! let result = unsafe { hello(ptr::null(), 0) };
 //! # assert_eq!(result, 42);
 //! #
@@ -97,7 +103,7 @@ pub mod nethost;
 
 /// Module containing a universal error enum for this crate.
 mod error;
-use error::*;
+pub use error::*;
 
 /// Module for a platform dependent c-like string type.
 pub mod pdcstring;
