@@ -1,7 +1,7 @@
 use std::path::Path;
 
-use netcorehost::nethost;
 use netcorehost::pdcstring::PdCString;
+use netcorehost::{nethost, pdcstr};
 use path_absolutize::Absolutize;
 
 #[path = "common.rs"]
@@ -18,15 +18,15 @@ fn runtime_properties() -> Result<(), Box<dyn std::error::Error>> {
     let context =
         hostfxr.initialize_for_runtime_config(&PdCString::from_os_str(runtime_config_path)?)?;
 
-    let test_property_name = PdCString::from_str("TEST_PROPERTY")?;
-    let test_property_value = PdCString::from_str("TEST_VALUE")?;
+    let test_property_name = pdcstr!("TEST_PROPERTY");
+    let test_property_value = pdcstr!("TEST_VALUE");
     context.set_runtime_property_value(&test_property_name, &test_property_value)?;
     let property_value = context.get_runtime_property_value_owned(&test_property_name)?;
-    assert_eq!(test_property_value, property_value);
+    assert_eq!(test_property_value, property_value.as_ref());
 
     let properties = context.get_runtime_properties_owned_as_map()?;
-    let property_value = properties.get(&test_property_name).unwrap();
-    assert_eq!(test_property_value, *property_value);
+    let property_value = properties.get(test_property_name).unwrap();
+    assert_eq!(test_property_value, property_value.as_ref());
 
     Ok(())
 }
